#
# spec file for package fcitx5-configtool
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor qt6%{nil}
%global sname fcitx5-configtool
%if "%{flavor}" == ""
%global pname %sname
%else
%global pname %{sname}-%{flavor}
%endif

# define lua macro to distinguish older kcm places from newer ones
%define is_old_kcm %{lua: if posix.access("%{_datadir}/kservices5") then print(1) else print(0) end}

Name:           %pname
Version:        5.1.7
Release:        1.1
Summary:        Configuration tool for fcitx5
License:        GPL-2.0-or-later
Group:          System/I18n/Chinese
URL:            https://github.com/fcitx/fcitx5-configtool
Source:         https://download.fcitx-im.org/fcitx5/%{sname}/%{sname}-%{version}.tar.zst
Patch1:         %{sname}-gcc7.patch
BuildRequires:  cmake
BuildRequires:  extra-cmake-modules
BuildRequires:  fcitx5-devel
BuildRequires:  fcitx5-qt-devel
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
%if "%{flavor}" == ""
BuildRequires:  libQt5QuickControls2-devel
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  libqt5-qtsvg-devel
BuildRequires:  libqt5-qtx11extras-devel
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5Declarative)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5IconThemes)
BuildRequires:  cmake(KF5ItemViews)
BuildRequires:  cmake(KF5Kirigami2)
BuildRequires:  cmake(KF5Package)
BuildRequires:  cmake(KF5Plasma)
BuildRequires:  cmake(KF5WidgetsAddons)
Conflicts:      %{sname}-qt6
%endif
%if "%{flavor}" == "qt6"
BuildRequires:  libplasma6-devel
BuildRequires:  qt6-concurrent-devel
BuildRequires:  qt6-quickcontrols2-devel
BuildRequires:  qt6-widgets-devel
BuildRequires:  cmake(KF6CoreAddons)
BuildRequires:  cmake(KF6Declarative)
BuildRequires:  cmake(KF6I18n)
BuildRequires:  cmake(KF6IconThemes)
BuildRequires:  cmake(KF6ItemViews)
BuildRequires:  cmake(KF6KCMUtils)
BuildRequires:  cmake(KF6Kirigami)
BuildRequires:  cmake(KF6Package)
BuildRequires:  cmake(KF6Svg)
Conflicts:      %{sname}
%endif
BuildRequires:  zstd
BuildRequires:  pkgconfig(iso-codes)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  pkgconfig(xkbfile)
Supplements:    fcitx5
Provides:       fcitx-config-gtk3 = %{version}
Obsoletes:      fcitx-config-gtk3 <= 0.4.10

%description
Configuration tool for fcitx5

%if "%{flavor}" == ""
%package -n kcm_fcitx5
Summary:        Configuration module for fcitx5
Group:          System/I18n/Chinese
Supplements:    (fcitx5 and plasma5-workspace)
Provides:       kcm5-fcitx = %{version}
Provides:       kf5-kcm-fcitx = %{version}
Provides:       kf5-kcm-fcitx-icons = %{version}
Obsoletes:      kcm5-fcitx <= 0.5.6
Obsoletes:      kf5-kcm-fcitx <= 0.5.6
Obsoletes:      kf5-kcm-fcitx-icons <= 0.5.6
Conflicts:      %{sname}-kcm6

%description -n kcm_fcitx5
Configuration module for fcitx5
%endif

%if "%{flavor}" == "qt6"
%package -n %{sname}-kcm6
Summary:        Configuration module for fcitx5
Group:          System/I18n/Chinese
Supplements:    (fcitx5 and plasma6-workspace)
Conflicts:      kcm_fcitx5

%description -n %{sname}-kcm6
Configuration module for fcitx5
%endif

%prep
%setup -q -n %{sname}-%{version}
%autopatch -p1

%build
%if "%{flavor}" == ""
%cmake -DUSE_QT6=OFF
%endif
%if "%{flavor}" == "qt6"
%cmake
%endif
%make_build

%install
%cmake_install
cat /usr/lib/rpm/suse/macros | grep suse_version

%find_lang kcm_fcitx5
%find_lang %{sname}
%suse_update_desktop_file kbd-layout-viewer5 Qt KDE Utility DesktopUtility
%suse_update_desktop_file org.fcitx.fcitx5-migrator Qt KDE Utility DesktopUtility

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%if "%{flavor}" == ""
%post -n kcm_fcitx5 -p /sbin/ldconfig
%postun -n kcm_fcitx5 -p /sbin/ldconfig
%endif
%if "%{flavor}" == "qt6"
%post -n %{sname}-kcm6 -p /sbin/ldconfig
%postun -n %{sname}-kcm6 -p /sbin/ldconfig
%endif

%files -f %{sname}.lang
%license LICENSES
%{_bindir}/fcitx5-config-qt
%{_bindir}/fcitx5-migrator
%{_bindir}/kbd-layout-viewer5
%{_datadir}/applications/org.fcitx.fcitx5-config-qt.desktop
%{_datadir}/applications/org.fcitx.fcitx5-migrator.desktop
%{_libdir}/libFcitx5Migrator.so*
%{_datadir}/applications/kbd-layout-viewer5.desktop

%if "%{flavor}" == ""
%files -n kcm_fcitx5 -f kcm_fcitx5.lang
%{_bindir}/fcitx5-plasma-theme-generator
%if 0%{?is_old_kcm}
%dir %{_libdir}/qt5/plugins/kcms
%dir %{_datadir}/kservices5
%{_libdir}/qt5/plugins/kcms/kcm_fcitx5.so
%{_datadir}/kservices5/kcm_fcitx5.desktop
%else
%dir %{_datadir}/kpackage
%dir %{_datadir}/kpackage/kcms
%dir %{_libdir}/qt5/plugins/plasma
%dir %{_libdir}/qt5/plugins/plasma/kcms
%dir %{_libdir}/qt5/plugins/plasma/kcms/systemsettings
%{_libdir}/qt5/plugins/plasma/kcms/systemsettings/kcm_fcitx5.so
%{_datadir}/applications/kcm_fcitx5.desktop
%{_datadir}/kpackage/kcms/kcm_fcitx5
%endif
%endif
%if "%{flavor}" == "qt6"
%files -n %{sname}-kcm6 -f kcm_fcitx5.lang
%{_bindir}/fcitx5-plasma-theme-generator
%{_libdir}/qt6/plugins/plasma/kcms/systemsettings/kcm_fcitx5.so
%{_datadir}/applications/kcm_fcitx5.desktop
%endif

%changelog
* Mon Jan  6 2025 Marguerite Su <i@marguerite.su>
- use lua macro to distinguish older kcm locations from newer ones,
  eg: 15.5 and 15.6 both have suse_version = 1500, but the former's
  kcm location is /usr/lib64/qt5/plugins/kcms while the later's kcm
  is placed at /usr/lib64/qt5/plugins/plasma/kcms
* Sun Jan  5 2025 Marguerite Su <i@marguerite.su>
- update version 5.1.7
  * translation update
- changes in 5.1.6
  * directly launch external tool if ExternalOption is the only option
- changes in 5.1.5
  * Don't use migrators in string
  * Support empty enum name
  * Variable name and other clean up
  * fix: select all checkbox inconsistent
  * Use Qt6 by default
- changes in 5.1.4
  * Fix return key drawn incorrectly
  * Fix usage of ListSectionHeader
* Thu May 23 2024 Marguerite Su <i@marguerite.su>
- add Conflicts so users can switch between plasma5 and plasma6
* Mon Feb  5 2024 Marguerite Su <i@marguerite.su>
- update to 5.1.3
  * add support to new CanRestart dbus api
  * fix build and adapt to kirigami change
  * improve option widget width
  * further improve layout
  * add desktop file
  * fix kcm discovery under KDE
  * fix directory name
  * rename po and kpackage to kcm_fcitx5
  * improve config UI layout
  * add support for qt6 wrapper
  * fix listview and ListItemDragHandle usage
  * improve long list option
  * fix KeyOption since eventToString was changed
  * allow void symbol
  * fix missing arg name
  * fix wrong header path
  * port to Qt6/KF6
  * install desktop to appdir
  * transition to json metadata
  * get rid of qtkeytrans since non-*nix platform is not relevant
- changes in 5.1.2
  * use actual comment bounding rect to calculate the size hint
* Tue Oct  3 2023 Marguerite Su <i@marguerite.su>
- update to 5.1.1
  * due to a fix in ECM, the SO version will change.
    adapt to the change to make it consistently produce
    the same SO version on old and new ECM.
* Sun Aug 20 2023 Marguerite Su <i@marguerite.su>
- update to 5.1.0
  * support new page button align mode in plasma theme generator
* Mon May 22 2023 Marguerite Su <i@marguerite.su>
- Update to 5.0.17
  * show more warning information when use disable addon
* Sun Nov 20 2022 Fusion Future <qydwhotmail@gmail.com>
- Update to 5.0.16
  * theme generator will now consider if the theme supports blur
- Remove obsolete patch
  * fcitx5-configtool-qt-5.9.patch
* Wed Sep 21 2022 Marguerite Su <i@marguerite.su>
- update version 5.0.15
  * fix the plasma theme generator reloading and add support
    for blur mask
* Tue Jul  5 2022 Fusion Future <qydwhotmail@gmail.com>
- Update to 5.0.14
  * Support for plasma themes in classicui
- BuildRequires cmake(KF5IconThemes) and cmake(KF5Plasma)
- Add new file fcitx5-plasma-theme-generator
- Use cmake() and pkgconfig() in BuildRequires
* Sat Mar 12 2022 Marguerite Su <i@marguerite.su>
- update version 5.0.12
  * force scroll by item
* Sat Jan 29 2022 Marguerite Su <i@marguerite.su>
- add subpackage kcm_fcitx5 and not auto install it for no KDE desktop
* Tue Jan 25 2022 Marguerite Su <i@marguerite.su>
- update to version 5.0.10
  * show a warning kbd-layout-viewer on wayland
* Sat Jan 15 2022 Marguerite Su <i@marguerite.su>
- fix requirements
* Wed Dec  8 2021 Tranter Madi <trmdi@yandex.com>
- update to version 5.0.9
* Sat Nov  6 2021 J <hj@powersnail.com>
- update to version 5.0.8
  * Fix font option for certain values.
  * Able to show long font name in font button
* Wed May  5 2021 Marguerite Su <i@marguerite.su>
- update version 5.0.5
  * Update the cancel button text to be more concrete
- changes in version 5.0.4
  * Add GUI option to reload newly installed addons
- drop fcitx5-configtool-ecm-5.80.patch, upstreamed
* Tue Mar 16 2021 Marguerite Su <i@marguerite.su>
- update version 5.0.3
  * fix kcm's color option
  * fix font option
* Sun Jan 31 2021 Marguerite Su <i@marguerite.su>
- update version 5.0.2
  * Make configtool not crash under wayland when open keyboard layout
  * Make it buildable with Qt 5.12, so it should be buildable on Ubuntu 20.04.
  * Add support for launch a sub config page
* Sun Dec  6 2020 Marguerite Su <i@marguerite.su>
- update version 5.0.1
* Tue Nov 10 2020 Marguerite Su <i@marguerite.su>
- update version 5.0.0
* Sun Oct 18 2020 xia lei <emricg2@gmail.com>
- update to 0.5.99+git20200903.583e3b2
  * add migration tool fcitx5-migrator
* Fri Sep  4 2020 Marguerite Su <i@marguerite.su>
- initial package
